#
# spec file for package kosmindoormap
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 1
%bcond_without released
Name:           kosmindoormap
Version:        23.08.4
Release:        1.2
Summary:        OSM indoor map QML component
License:        LGPL-2.0-or-later AND CC0-1.0
URL:            https://apps.kde.org/kosmindoormap
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  bison
BuildRequires:  extra-cmake-modules
BuildRequires:  flex
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KOpeningHours)
BuildRequires:  cmake(KPublicTransport)
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(zlib)
Requires:       libKOSM%{soversion} = %{version}

%description
QML components for KDE Itinerary.

%package -n libKOSM%{soversion}
Summary:        OSM primitives for kosmindoormap

%description -n libKOSM%{soversion}
OSM primitives for kosmindoormap.

%package -n libKOSMIndoorMap%{soversion}
Summary:        OSM multi-floor indoor map renderer

%description -n libKOSMIndoorMap%{soversion}
OSM multi-floor indoor map renderer library.

%package devel
Summary:        Development package for kosmindoormap
Requires:       libKOSM%{soversion} = %{version}
Requires:       libKOSMIndoorMap%{soversion} = %{version}

%description devel
This package contains development files for the KOSM and KOSMIndoorMap libraries.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DBUILD_TESTING=ON

%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name}

%check
# Two tests fail on i586 (one minor floating point issue and a color one).
# Upstream is investigating
%ifnarch i586
%ctest
%endif

%ldconfig_scriptlets -n libKOSM%{soversion}
%ldconfig_scriptlets -n libKOSMIndoorMap%{soversion}

%files
%license LICENSES/*
%doc README.md
%dir %{_kf5_qmldir}/org
%dir %{_kf5_qmldir}/org/kde
%{_kf5_debugdir}/org_kde_kosmindoormap.categories
%{_kf5_qmldir}/org/kde/kosmindoormap/

%files -n libKOSM%{soversion}
%{_kf5_libdir}/libKOSM.so.*

%files -n libKOSMIndoorMap%{soversion}
%{_kf5_libdir}/libKOSMIndoorMap.so.*

%files devel
%{_includedir}/KOSM/
%{_includedir}/KOSMIndoorMap/
%{_includedir}/kosm/
%{_includedir}/kosmindoormap/
%{_includedir}/kosmindoormap_version.h
%{_kf5_cmakedir}/KOSMIndoorMap/
%{_kf5_libdir}/libKOSM.so
%{_kf5_libdir}/libKOSMIndoorMap.so

%files lang -f %{name}.lang

%changelog
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Render waterfalls, public book cases and co-working spaces
  * Match not found tag keys against the KeyNotSet operator
  * Improve rendering of some tourist attractions
  * Handle another Wikepedia link tagging variant
  * Render showers as well
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Handle another luggage locker tagging variant
  * Show the type of diplomatic entities in the info box
  * Add consulate icon, show labels for embassys
  * Render food courts, clinics and an alternative travel agency tagging
  * Handle network:wikipedia tags in the same way we handle operator:wikipedia
  * Display lost & found offices
  * Display airport baggage claim belts
  * Add luggage locker icon
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Add luggage locker icon
  * Fix rendering of closed non-area walls
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Use protobuf's cmake config if available
  * Use protobuf cmake targets instead of variables
  * Show transliterated names when available and useful
  * .gitignore ignore compile_commands.json
  * Explicitly set target interface include directories
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Consider local names as alternative when no element name is available
  * Enable info boxes for trees
  * Fix hit detection for icons using a physical size
  * Implement MapCSS text-position declarations properly
  * Render kerb lines much less prominently
  * Support setting negative numeric tag values in MapCSS
  * Better distinguish rendering of different barrier types
  * Render shrubs
  * Fix display of service roads in light style
  * Add User-Agent header for downloading map tiles
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Fill in missing country/state information based on the coordinate
  * Port deprecated QStandardPaths::DataLocation
  * Add basic translation for boolean-like tag values
  * Port rental vehicle details to KLazyLocalizedString as well
  * Port static message tables from I18N_NOOP to KLazyLocalizedString
  * Translate title
  * Setup Gitlab CI
  * Try to activate new CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Format user visible numbers using the current locale
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Allow the platform model to match platforms on all their properties
  * Add properties to Platform for direct access from QML
  * Remove the Platform::lines public member
  * Add dptr to Platform as well
  * Prepare PlatformSection to become proper public API
  * Don't attempt platform section merging when there is only one
  * Fix pinch zoom conflicting with map panning
  * Consider IFOPT platform ids for merging platform elements
  * Ignore disused platform elements
  * Add styling for tourism=gallery
  * Show details about available rental vehicles
  * Also expose the available vehicles by type for rental docks
  * Implement pole of inaccessibility algorithm
  * Separate dock-based and floating rental vehicles
  * Port to the new logging category macros
  * Port from QStringRef to QStringView
  * Display remaining range of rental vehicles when available
  * Add corresponding icons for all free-floating rental vehicle types
  * Give free-floating rental kick scooters their own icon
  * Add CMakePresets support
  * It compiles without deprecated method
  * Upgrade to KDECompilerSettings 5.85
  * replace "MacOSX" with "macOS"
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Properly handle intermediate floor levels in equipment model
  * Handle another way of tagging emankments
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Work around CMake Protobuf support not dealing with missing protoc
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Migrate to new REUSE CI check
  * Also show tracks and paths
  * Use the newly supported layer selectors to untangle roads and tramways
  * Add layer selector support to the scene graph
  * Implement layer selector support in MapCSS union selectors
  * Prepare MapCSS selector matching to support layer selectors
  * Prepare MapCSSResult for carrying results for multiple layer selectors
  * Handle default layer selector
  * Use unique string keys for class and layer selectors
  * Factor out the  unique string key pool from OSM::DataSet
  * Expand MapCSS grammar for supporting layer selectors
  * Handle another way of tagging inaccessible elevators
  * Add i18n context for "socket"
  * Add information icons from OSM carto
  * Increase the minimum Qt version to 5.15 here too
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Remove the boundary filter
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Actually build without QtWidgets
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Massively reduce the node matching distance for geometry reassembly
  * Fix build with Qt 5.14
  * Enable HTTP2 support when available
  * Set SOVERSION to a fixed value
  * Fix 32bit color parsing on 32bit architectures
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Initial package
